
======================  =============  =======  ===========================   
Key                     Type           Options  Default                      Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        
======================  =============  =======  ===========================   
``key``                 str            ..       ``SNRG``                     Keyword to distinguish the assessment method.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      
``waverange``           ndarray, list  ..       ..                           A two-element vector with the starting and ending wavelength within which to calculate the signal-to-noise.  Mutually exclusive with response_func_file                                                                                                                                                                                                                                                                                                                                                                                                            
``response_func_file``  str            ..       ``gunn_2001_g_response.db``  The name of a file that defines a response function to use for the S/N calculation.  Must be a local file or distributed with the DAP source code.  Expected to have two columns, with the wavelength and response efficiency.  Mutually exclusive with waverange.                                                                                                                                                                                                                                                                                                 
``in_vacuum``           bool           ..       True                         Boolean indicating that the wavelengths provided either using waverange or response_func_file are in vacuum (not air).                                                                                                                                                                                                                                                                                                                                                                                                                                             
``covariance``          bool           ..       True                         Provide the fiducial spatial covariance.  If this is False, no spatial covariance will be available for calculations that use the results of the reduction assessments.  If True and a covariance matrix is available directly from the datacube, it will be used.  If True and the datacube does not already provide a computed covariance matrix, one is calculated using :func:`~mangadap.datacube.datacube.DataCube.covariance_matrix` method.  **WARNING**: If either of these fail, the DAP will issue a warning and continue assuming no spatial covariance.
``minimum_frac``        int, float     ..       0.8                          Minimum fraction of unmasked pixels in a spectrum required for inclusion in the spatial covariance calculation.  Note this should match the value used for the spatial-binning module.                                                                                                                                                                                                                                                                                                                                                                             
``overwrite``           bool           ..       False                        If the output file already exists, redo all the calculations and overwrite it.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     
======================  =============  =======  ===========================   

